Skip to contents

This is a dataset that contains the list of journal rankings from the ARC Excellence in Research for Australia 2010 round.

Usage

data(era2010)

Format

An object of class tbl_df (inherits from tbl, data.frame) with 20712 rows and 5 columns.

Value

A data frame with 20712 rows and the following 5 variables:

eraid:

ERA ID of the journal

title:

Title of the journal

issn:

International Standard Serial Number

field_of_research:

Field of Research Code as provided by the Australian Bureau of Statistics at the time. Note that the codes have since changed.

rank:

In order of best to lowest rank: A*, A, B, or C

Examples

library(dplyr)
era2010 |>
  filter(field_of_research == "0104") |>
  arrange(rank)
#> # A tibble: 162 × 5
#>    eraid title                                     issn  field_of_research rank 
#>    <dbl> <chr>                                     <chr> <chr>             <ord>
#>  1   774 Annals of Applied Probability             1050… 0104              A*   
#>  2   880 Annals of Applied Statistics              1932… 0104              A*   
#>  3   775 Annals of Probability                     0091… 0104              A*   
#>  4   776 Annals of Statistics                      0090… 0104              A*   
#>  5 39798 Bioinformatics                            1367… 0104              A*   
#>  6 32526 Biometrics                                0006… 0104              A*   
#>  7   922 Biometrika                                0006… 0104              A*   
#>  8 40721 Biostatistics                             1465… 0104              A*   
#>  9   811 Journal of Business and Economic Statist… 0735… 0104              A*   
#> 10   813 Journal of Computational and Graphical S… 1061… 0104              A*   
#> # ℹ 152 more rows