Skip to contents

Retrieves publications for given Google Scholar IDs, and returns them as a tibble. This function retrieves publications for a given Google Scholar ID and formats them into a structured tibble.

Usage

fetch_scholar(scholar_id)

Arguments

scholar_id

A character vector of Google Scholar IDs.

Value

A tibble containing all publications for the specified Google Scholar IDs.

Examples

if (FALSE) { # \dontrun{
fetch_scholar("vamErfkAAAAJ")
} # }